<?php
function _addKeywords(&$tof,$vars) {
	require_once("actions/keywords.php");
	addKeywords(
		$tof,
		$vars['Pictures'],
		$vars['TypeID'],
		$vars['KeywordValue']);
}
?>